# eric7.Plugins.VcsPlugins.vcsPySvn.ProjectHelper

Module implementing the VCS project helper for Subversion.

### Global Attributes

None

### Classes

PySvnProjectHelper | Class implementing the VCS project helper for Subversion.

### Functions

None

## PySvnProjectHelper

Class implementing the VCS project helper for Subversion.

### Derived from

VcsProjectHelper

### Class Attributes

None

### Class Methods

None

### Methods

PySvnProjectHelper | Constructor
__svnBranchList | Private slot used to list the branches of the project.
__svnChangeLists | Private slot used to show a list of change lists.
__svnConfigure | Private slot to open the configuration dialog.
__svnExtendedDiff | Private slot used to perform a svn diff with the selection of revisions.
__svnInfo | Private slot used to show repository information for the local project.
__svnPropDel | Private slot used to delete a property for the project files.
__svnPropList | Private slot used to list the properties of the project files.
__svnPropSet | Private slot used to set a property for the project files.
__svnRelocate | Private slot used to relocate the working copy to a new repository URL.
__svnRepoBrowser | Private slot to open the repository browser.
__svnResolve | Private slot used to resolve conflicts of the local project.
__svnTagList | Private slot used to list the tags of the project.
__svnUpgrade | Private slot used to upgrade the working copy format.
__svnUrlDiff | Private slot used to perform a svn diff with the selection of repository URLs.
getActions | Public method to get a list of all actions.
initActions | Public method to generate the action objects.
initMenu | Public method to generate the VCS menu.
initToolbar | Public slot to initialize the VCS toolbar.
removeToolbar | Public method to remove a toolbar created by initToolbar().

### Static Methods

None

#### PySvnProjectHelper (Constructor)

PySvnProjectHelper(vcsObject, projectObject, parent=None, name=None)

Constructor

vcsObject
  reference to the vcs object
projectObject
  reference to the project object
parent
  parent widget (QWidget)
name
  name of this object (string)

#### PySvnProjectHelper.__svnBranchList

__svnBranchList()

Private slot used to list the branches of the project.

#### PySvnProjectHelper.__svnChangeLists

__svnChangeLists()

Private slot used to show a list of change lists.

#### PySvnProjectHelper.__svnConfigure

__svnConfigure()

Private slot to open the configuration dialog.

#### PySvnProjectHelper.__svnExtendedDiff

__svnExtendedDiff()

Private slot used to perform a svn diff with the selection of revisions.

#### PySvnProjectHelper.__svnInfo

__svnInfo()

Private slot used to show repository information for the local project.

#### PySvnProjectHelper.__svnPropDel

__svnPropDel()

Private slot used to delete a property for the project files.

#### PySvnProjectHelper.__svnPropList

__svnPropList()

Private slot used to list the properties of the project files.

#### PySvnProjectHelper.__svnPropSet

__svnPropSet()

Private slot used to set a property for the project files.

#### PySvnProjectHelper.__svnRelocate

__svnRelocate()

Private slot used to relocate the working copy to a new repository URL.

#### PySvnProjectHelper.__svnRepoBrowser

__svnRepoBrowser()

Private slot to open the repository browser.

#### PySvnProjectHelper.__svnResolve

__svnResolve()

Private slot used to resolve conflicts of the local project.

#### PySvnProjectHelper.__svnTagList

__svnTagList()

Private slot used to list the tags of the project.

#### PySvnProjectHelper.__svnUpgrade

__svnUpgrade()

Private slot used to upgrade the working copy format.

#### PySvnProjectHelper.__svnUrlDiff

__svnUrlDiff()

Private slot used to perform a svn diff with the selection of repository URLs.

#### PySvnProjectHelper.getActions

getActions()

Public method to get a list of all actions.

Return:
  list of all actions (list of EricAction)

#### PySvnProjectHelper.initActions

initActions()

Public method to generate the action objects.

#### PySvnProjectHelper.initMenu

initMenu(menu)

Public method to generate the VCS menu.

menu
  reference to the menu to be populated (QMenu)

#### PySvnProjectHelper.initToolbar

initToolbar(ui, toolbarManager)

Public slot to initialize the VCS toolbar.

ui
  reference to the main window (UserInterface)
toolbarManager
  reference to a toolbar manager object (EricToolBarManager)

#### PySvnProjectHelper.removeToolbar

removeToolbar(ui, toolbarManager)

Public method to remove a toolbar created by initToolbar().

ui
  reference to the main window (UserInterface)
toolbarManager
  reference to a toolbar manager object (EricToolBarManager)

Up